from .madp_object import MAD

__title__ = "pymadng"
__version__ = "0.7.1"

__summary__ = "Python interface to MAD-NG running as subprocess"
__uri__ = "https://github.com/MethodicalAcceleratorDesign/MAD-NG.py"

__credits__ = """
Creator: Joshua Gray <joshua.mark.gray at cern.ch>
"""

__all__ = ["MAD"]
